@@ -250,10 +250,10 @@ void Controller::playVideo(const QString &url) {
 void Controller::deleteVideo(const QString &path) {
     if (QFile::exists(path)) {
         if (QFile::remove(path)) {
-            emit alert(tr("Video deleted from device"));
+            emit alert(tr("Video(s) deleted from device"));
         }
         else {
-            emit alert(tr("Unable to delete video"));
+            emit alert(tr("Unable to delete video(s) from device"));
         }
     }
     else {
