@@ -30,7 +30,7 @@ void DownloadManager::setDownloadQuality(const QString &quality) {
 void DownloadManager::getVideoUrl(const QString &playerUrl) {
     QString url = playerUrl;
     QString videoId = url.split("v=").last().split("&").first();
-    QString pageUrl = "http://www.youtube.com/get_video_info?&video_id=" + videoId.toAscii() + "&ps=default&eurl=&gl=US&hl=en";
+    QString pageUrl = "http://www.youtube.com/get_video_info?&video_id=" + videoId.toAscii() + "&el=detailpage&ps=default&eurl=&gl=US&hl=en";
     downloadReply = nam->get(QNetworkRequest(QUrl(pageUrl)));
     connect(downloadReply, SIGNAL(finished()), this, SLOT(parseVideoPage()));
 }
