@@ -141,7 +141,7 @@ function setDefaultSettings() {
                     [ "screenOrientation", "automatic" ],
                     [ "mediaPlayer", "Media Player" ],
                     [ "searchOrder", "relevance" ],
-                    [ "theme", "dark" ],
+                    [ "theme", "night" ],
                     [ "language", "en" ],
                     [ "proxy", ":"],
                     [ "widgetFeedOne", "_MOST_RECENT_FEED" ],
