@@ -55,7 +55,6 @@ private slots:
     void deleteRequest(const QUrl &url);
     void postFinished();
     void parseVideoPage(QNetworkReply *reply);
-    void parseVideoPage();
 
 private:
     QNetworkAccessManager *nam;
@@ -77,16 +76,20 @@ signals:
     void currentUserChanged();
     void accessTokenChanged(const QString &token);
     void postSuccessful();
+    void postFailed();
     void addedToFavourites();
     void deletedFromFavourites();
+    void videoInFavourites();
     void addedToPlaylist();
     void deletedFromPlaylist();
     void playlistCreated();
+    void playlistDeleted();
     void subscribed();
     void unsubscribed();
     void uploadStarted();
     void commentAdded();
     void videoRated();
+    void cannotRate();
     void updateUploadProgress(qint64 bytesSent, qint64 bytesTotal);
     void uploadCompleted(const QString &status);
 };
